<?php

namespace Alike\Admin;

/**
*
*/
class Ra_Admin_API {

  public function __construct() {
    add_action( 'rest_api_init', [$this, 'get_all_post_data_endpoint'] );
    add_action( 'rest_api_init', [$this, 'get_post_meta'] );
  }

  function get_all_post_data_endpoint() {
    register_rest_route( 'alike/v1', '/data', array(
        'methods'  => \WP_REST_Server::READABLE,
        'callback' => [$this, 'get_all_post_data'],
    ) );
}

// 6. Callback function that performs custom logic
function get_all_post_data( $request ) {
    $parameters = $request->get_query_params(); 
    $return_type = isset($parameters['options']) ? $parameters['options'] : 'post_keys';
    
    $all_posts = [];
      // foreach ($allData as $data) {
         $post_type = isset($request['posttype']) ? $request['posttype'] : 'post';
        $all_posts = [
          'post_type' => $post_type,
          'taxonomy_keys' => $this->get_all_taxonomies($post_type),
          'term_keys'     => $this->get_terms_on_taxonomies($this->get_all_taxonomies($post_type)),
          'meta_keys'     => $this->get_meta_keys($post_type),
          'post_keys'     => [
            'post_thumbnail',
            'post_title',
            'post_title_link',
            'post_content',
            'post_excerpt',
            'woocommerce_price',
            'woocommerce_add_to_cart',
        ]
          ];

     return $all_posts[$return_type];
      
}

public function get_meta_keys($post_type) {    
    // Get all posts of the defined post type
    $posts = get_posts( array(
        'post_type' => $post_type,
        'posts_per_page' => -1,
        'post_status' => 'any',
    ) );
    
    // Initialize an array to store all meta keys
    $meta_keys = [];
    
    // Loop through all posts
    foreach ( $posts as $post ) {
        // Get all meta data for the current post
        $post_meta = get_post_meta( $post->ID );
        // Loop through all meta data
        foreach ( $post_meta as $meta_key => $meta_value ) {
            // Add the meta key to the array if it doesn't already exist
            if ( ! in_array( $meta_key, $meta_keys ) ) {
                if ( !preg_match( '/^_/', $meta_key ) ) {
                    $meta_keys[] = $meta_key;
                }  
            }
        }
    }
    
    // Output all meta keys
    return $meta_keys;
}

public function get_all_taxonomies( $post_types='post' )
  {
    $all_post_types = explode(",",$post_types);
    $taxonomies = array();
    foreach ($all_post_types as $type ) {
      $taxonomies = array_merge( $taxonomies, get_object_taxonomies( $type) ) ;
    }
    return $taxonomies;
  }

  public function get_terms_on_taxonomies( $taxonomies )
  {
    if( !empty($taxonomies) ){
      $all_data = array();
      foreach ($taxonomies as $taxonomy) {

        $categories = get_terms( $taxonomy , array('hide_empty' => false));
        $categoryHierarchy = array();
        $linar_order = array();
        $this->sort_terms_hierarchicaly($categories, $categoryHierarchy);
        $this->grab_in_linear( $categoryHierarchy, $taxonomy , $linar_order );
        $all_data[$taxonomy] = $linar_order;
        // $all_data[$taxonomy] = array(
        //   'linear' => $linar_order,
        //   // 'complex' => $categoryHierarchy
        // );
      }

      return $all_data;
    }
  }
  public function get_all_term_meta($term_id) {
    $result = array();
    $term_meta = array();
    $result = get_term_meta($term_id);
    foreach ($result as $key => $value) {
        if($value[0]){
          $image_full_url = wp_get_attachment_image_src($value[0]);
          $image_big_url = wp_get_attachment_image_src($value[0], array(600, 400));
          $image_medium_url = wp_get_attachment_image_src($value[0], array(300, 152));
          $image_small_url = wp_get_attachment_image_src($value[0], array(64, 64));
        }
      if(isset($image_full_url) && is_array($image_full_url)){
        $term_meta[] = array(
          $key => array(
            'image_full_url' => $image_full_url[0],
            'image_big_url' => $image_big_url[0],
            'image_medium_url' => $image_medium_url[0],
            'image_small_url' => $image_small_url[0]),
        );
      }
      else{
        $term_meta[] = array(
          $key => array($value[0]),
        );
      }
    }
  return $term_meta;
}

  public function sort_terms_hierarchicaly(Array &$cats, Array &$into, $parentId = 0) {
      foreach ($cats as $i => $cat) {
          if ($cat->parent == $parentId) {
              $into[] = $cat;
              unset($cats[$i]);
          }
      }
      foreach ($into as $topCat) {
          $topCat->children = array();
          $this->sort_terms_hierarchicaly($cats, $topCat->children, $topCat->term_id);
      }
  }
  function grab_in_linear( $cats , $taxonomy, &$result  ){
    if( is_array($cats) && count($cats) > 0 ){
      foreach ($cats as $cat) {
        $flag = false;
        foreach ($result as $term) {
          if($term['key'] == $cat->term_id){
            $flag = true;
          }
        }
        if( $flag == false  ){
          $level = count(get_ancestors( $cat->term_id, $taxonomy ) );
          $dash = "";
          for($i = 0; $i < $level; $i++  )
            $dash .= "  ";
          $result[] = array(
            'key'  => $cat->term_id,
            'value' => $dash.$cat->name,
            'slug' => $cat->slug,
            'count' => $cat->count,
            'parent' => $cat->parent,
            'term_meta' => $this->get_all_term_meta($cat->term_id),
          );
        }
        if( is_array( $cat->children ) && count($cat->children) > 0 ){
          $this->grab_in_linear($cat->children, $taxonomy , $result  );
        }
      }
    }
  }
  // get post meta 
  function get_post_meta() {
    // 3. Register a new route with the endpoint URL
    register_rest_route( 'alike/v1', '/meta', array(
        // 4. Define the endpoint methods (GET, POST, PUT, DELETE)
        'methods'  => \WP_REST_Server::READABLE,
        // 5. Callback function that performs custom logic
        'callback' => [$this, 'get_post_meta_data'],
    ) );
}
public function get_post_meta_data( $request ) {
  $parameters = $request->get_query_params(); 
  $return_id = isset($parameters['id']) ? $parameters['id'] : '';
  if($return_id == ''){
    return;
  }
  return get_post_meta($return_id, 'alike_post_type_meta', true);
}
} // end of class